Changes
=======

2.0 - Unreleased
----------------

- Add pyproject.toml with setuptools backend.
- Move configuration to setup.cfg.
- Add sphinx-quickstart generated docs.
- Setup sphinx-rtd-theme and tox for local previews.
- Drop Python 2 support.
- Move tests out of mypackage.
- Include tests in sdist but not in wheel.

1.0 - 2017-09-18
----------------

- Initial release.
